@@ -13,7 +13,3 @@ pub use binstalk_git_repo_api::gh_api_client;
 pub(crate) use cargo_toml_workspace::{self, cargo_toml};
 #[cfg(feature = "git")]
 pub(crate) use simple_git as git;
-
-pub(crate) fn is_universal_macos(target: &str) -> bool {
-    ["universal-apple-darwin", "universal2-apple-darwin"].contains(&target)
-}
